@@ -6,7 +6,7 @@ from pynamodb.expressions.condition import (
     BeginsWith, Between, Comparison, Contains, Exists, In, IsType, NotExists
 )
 from pynamodb.expressions.update import (
-    AddAction, DeleteAction, RemoveAction, SetAction
+    AddAction, DeleteAction, RemoveAction, SetAction, ListRemoveAction
 )
 from pynamodb.expressions.util import get_path_segments, get_value_placeholder, substitute_names
 from six import string_types
@@ -277,6 +277,9 @@ class Path(_NumericOperand, _ListAppendOperand, _ConditionOperand):
         # Returns an update action that removes this attribute from the item
         return RemoveAction(self)
 
+    def remove_list_elements(self, *indexes):
+        return ListRemoveAction(self, *indexes)
+
     def add(self, *values):
         # Returns an update action that appends the given values to a set or mathematically adds a value to a number
         value = values[0] if len(values) == 1 else values
